==> logtalk-3.45.0.tar.bz2: logtalk-3.45.0/library/assignvars/NOTES.md <==
________________________________________________________________________

This file is part of Logtalk <https://logtalk.org/>  
Copyright 1998-2021 Paulo Moura <pmoura@logtalk.org>
SPDX-License-Identifier: Apache-2.0

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
________________________________________________________________________


`assignvars`
============

The `assignvarsp` protocol declares the predicates used for logical assignment 
of Prolog terms developed by Nobukuni Kino.

The `assignvars` object provides a declarative implementation of the `assignvarsp`
protocol. It can be used with any backend Prolog compiler. 

The `nd_assignvars` object provides a non-declarative but faster implementation
of the `assignvarsp` protocol. It can be used with the following backend Prolog
compilers: B-Prolog, CxProlog, ECLiPSe, GNU Prolog, Qu-Prolog, SICStus Prolog,
SWI-Prolog, and YAP.

For more information on assignvars, please consult the URL:

	http://www.kprolog.com/en/logical_assignment/

The representation of assignable terms should be regarded as an opaque term and
only accessed using the library predicates.


API documentation
-----------------

Open the [../../docs/library_index.html#assignvars](../../docs/library_index.html#assignvars)
link in a web browser.


Loading
-------

To load all entities in this library, load the `loader.lgt` file:

	| ?- logtalk_load(assignvars(loader)).


Testing
-------

To test this library predicates, load the `tester.lgt` file:

	| ?- logtalk_load(coroutining(tester)).

==> logtalk-3.55.0.tar.bz2: logtalk-3.55.0/library/assignvars/NOTES.md <==
________________________________________________________________________

This file is part of Logtalk <https://logtalk.org/>  
Copyright 1998-2022 Paulo Moura <pmoura@logtalk.org>  
SPDX-License-Identifier: Apache-2.0

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
________________________________________________________________________


`assignvars`
============

The `assignvarsp` protocol declares the predicates used for logical assignment 
of Prolog terms developed by Nobukuni Kino.

The `assignvars` object provides a declarative implementation of the `assignvarsp`
protocol. It can be used with any backend Prolog compiler. 

The `nd_assignvars` object provides a non-declarative but faster implementation
of the `assignvarsp` protocol. It can be used with the following backend Prolog
compilers: B-Prolog, CxProlog, ECLiPSe, GNU Prolog, Qu-Prolog, SICStus Prolog,
SWI-Prolog, and YAP.

For more information on assignvars, please consult the URL:

https://web.archive.org/web/20160818050049/http://www.kprolog.com/en/logical_assignment/

The representation of assignable terms should be regarded as an opaque term and
only accessed using the library predicates.


API documentation
-----------------

Open the [../../docs/library_index.html#assignvars](../../docs/library_index.html#assignvars)
link in a web browser.


Loading
-------

To load all entities in this library, load the `loader.lgt` file:

	| ?- logtalk_load(assignvars(loader)).


Testing
-------

To test this library predicates, load the `tester.lgt` file:

	| ?- logtalk_load(coroutining(tester)).
